@@ -397,13 +397,19 @@ enum general
     General_Written_Location,
     General_Archival_Location,
     General_Encoded_Application,
+    General_Encoded_Application_String,
+    General_Encoded_Application_CompanyName,
+    General_Encoded_Application_Name,
+    General_Encoded_Application_Version,
     General_Encoded_Application_Url,
     General_Encoded_Library,
     General_Encoded_Library_String,
+    General_Encoded_Library_CompanyName,
     General_Encoded_Library_Name,
     General_Encoded_Library_Version,
     General_Encoded_Library_Date,
     General_Encoded_Library_Settings,
+    General_Encoded_OperatingSystem,
     General_Cropped,
     General_Dimensions,
     General_DotsPerInch,
@@ -588,20 +594,28 @@ enum video
     Video_Width_Offset_String,
     Video_Width_Original,
     Video_Width_Original_String,
+    Video_Width_CleanAperture,
+    Video_Width_CleanAperture_String,
     Video_Height,
     Video_Height_String,
     Video_Height_Offset,
     Video_Height_Offset_String,
     Video_Height_Original,
     Video_Height_Original_String,
+    Video_Height_CleanAperture,
+    Video_Height_CleanAperture_String,
     Video_PixelAspectRatio,
     Video_PixelAspectRatio_String,
     Video_PixelAspectRatio_Original,
     Video_PixelAspectRatio_Original_String,
+    Video_PixelAspectRatio_CleanAperture,
+    Video_PixelAspectRatio_CleanAperture_String,
     Video_DisplayAspectRatio,
     Video_DisplayAspectRatio_String,
     Video_DisplayAspectRatio_Original,
     Video_DisplayAspectRatio_Original_String,
+    Video_DisplayAspectRatio_CleanAperture,
+    Video_DisplayAspectRatio_CleanAperture_String,
     Video_ActiveFormatDescription,
     Video_ActiveFormatDescription_String,
     Video_ActiveFormatDescription_MuxingMode,
@@ -722,13 +736,19 @@ enum video
     Video_Alignment_String,
     Video_Title,
     Video_Encoded_Application,
+    Video_Encoded_Application_String,
+    Video_Encoded_Application_CompanyName,
+    Video_Encoded_Application_Name,
+    Video_Encoded_Application_Version,
     Video_Encoded_Application_Url,
     Video_Encoded_Library,
     Video_Encoded_Library_String,
+    Video_Encoded_Library_CompanyName,
     Video_Encoded_Library_Name,
     Video_Encoded_Library_Version,
     Video_Encoded_Library_Date,
     Video_Encoded_Library_Settings,
+    Video_Encoded_OperatingSystem,
     Video_Language,
     Video_Language_String,
     Video_Language_String1,
@@ -744,11 +764,11 @@ enum video
     Video_Tagged_Date,
     Video_Encryption,
     Video_BufferSize,
+    Video_colour_range,
     Video_colour_description_present,
     Video_colour_primaries,
     Video_transfer_characteristics,
     Video_matrix_coefficients,
-    Video_colour_range,
     Video_colour_description_present_Original,
     Video_colour_primaries_Original,
     Video_transfer_characteristics_Original,
@@ -984,12 +1004,20 @@ enum audio
     Audio_Interleave_Preload,
     Audio_Interleave_Preload_String,
     Audio_Title,
+    Audio_Encoded_Application,
+    Audio_Encoded_Application_String,
+    Audio_Encoded_Application_CompanyName,
+    Audio_Encoded_Application_Name,
+    Audio_Encoded_Application_Version,
+    Audio_Encoded_Application_Url,
     Audio_Encoded_Library,
     Audio_Encoded_Library_String,
+    Audio_Encoded_Library_CompanyName,
     Audio_Encoded_Library_Name,
     Audio_Encoded_Library_Version,
     Audio_Encoded_Library_Date,
     Audio_Encoded_Library_Settings,
+    Audio_Encoded_OperatingSystem,
     Audio_Language,
     Audio_Language_String,
     Audio_Language_String1,
@@ -1198,12 +1226,20 @@ enum text
     Text_Source_StreamSize_Encoded_String5,
     Text_Source_StreamSize_Encoded_Proportion,
     Text_Title,
+    Text_Encoded_Application,
+    Text_Encoded_Application_String,
+    Text_Encoded_Application_CompanyName,
+    Text_Encoded_Application_Name,
+    Text_Encoded_Application_Version,
+    Text_Encoded_Application_Url,
     Text_Encoded_Library,
     Text_Encoded_Library_String,
+    Text_Encoded_Library_CompanyName,
     Text_Encoded_Library_Name,
     Text_Encoded_Library_Version,
     Text_Encoded_Library_Date,
     Text_Encoded_Library_Settings,
+    Text_Encoded_OperatingSystem,
     Text_Language,
     Text_Language_String,
     Text_Language_String1,
