@@ -284,9 +284,6 @@ File_Dpx::File_Dpx()
 //---------------------------------------------------------------------------
 void File_Dpx::Streams_Accept()
 {
-    Fill(Stream_General, 0, General_Format, "DPX");
-    Fill(Stream_General, 0, General_Format_Version, Version==1?"Version 1":"Version 2");
-
     if (!IsSub)
     {
         TestContinuousFileNames();
@@ -302,7 +299,6 @@ void File_Dpx::Streams_Accept()
 
     //Configuration
     Buffer_MaximumSize=64*1024*1024; //Some big frames are possible (e.g YUV 4:2:2 10 bits 1080p)
-    Frame_Count_NotParsedIncluded=0;
 }
 
 //***************************************************************************
@@ -319,10 +315,10 @@ bool File_Dpx::FileHeader_Begin()
     int32u Magic=CC4(Buffer);
     switch (Magic)
     {
-        case 0x802A5FD7 :   //       (v1 Big)
-        case 0xD75F2A80 :   //       (v1 Little)
-        case 0x53445058 :   //"SPDX" (v2 Big)
-        case 0x58504453 :   //"XDPS" (v2 Little)
+        case 0x802A5FD7 :   //       (Cineon Big)
+        case 0xD75F2A80 :   //       (Cineon Little)
+        case 0x53445058 :   //"SPDX" (Dpx Big)
+        case 0x58504453 :   //"XDPS" (Dpx Little)
                             break;
         default         :
                             Reject();
@@ -335,24 +331,24 @@ bool File_Dpx::FileHeader_Begin()
     Sizes_Pos=Pos_GenericSection;
     switch (Magic)
     {
-        case 0x802A5FD7 :   //       (v1 Big)
-        case 0xD75F2A80 :   //       (v1 Little)
-                            Version=1;
+        case 0x802A5FD7 :   //       (Cineon Big)
+        case 0xD75F2A80 :   //       (Cineon Little)
+                            IsDpx=false;
                             break;
-        case 0x58504453 :   //"XDPS" (v2 Little)
-        case 0x53445058 :   //"SPDX" (v2 Big)
-                            Version=2;
+        case 0x58504453 :   //"XDPS" (Dpx Little)
+        case 0x53445058 :   //"SPDX" (Dpx Big)
+                            IsDpx=true;
                             break;
         default         :   ;
     }
     switch (Magic)
     {
-        case 0xD75F2A80 :   //       (v1 Little)
-        case 0x58504453 :   //"XDPS" (v2 Little)
+        case 0xD75F2A80 :   //       (Cineon Little)
+        case 0x58504453 :   //"XDPS" (Dpx Little)
                             LittleEndian=true;
                             break;
-        case 0x802A5FD7 :   //       (v1 Big)
-        case 0x53445058 :   //"SPDX" (v2 Big)
+        case 0x802A5FD7 :   //       (Cineon Big)
+        case 0x53445058 :   //"SPDX" (Dpx Big)
                             LittleEndian=false;
                             break;
         default         :   ;
@@ -392,13 +388,13 @@ void File_Dpx::Header_Parse()
 //---------------------------------------------------------------------------
 void File_Dpx::Data_Parse()
 {
-    if (Version==1)
+    if (!IsDpx) // Is Cineon
     {
         switch (Element_Code)
         {
-            case Pos_GenericSection   : GenericSectionHeader_v1(); break;
-            case Pos_IndustrySpecific : IndustrySpecificHeader_v1(); break;
-            case Pos_UserDefined      : UserDefinedHeader_v1(); break;
+            case Pos_GenericSection   : GenericSectionHeader_Cineon(); break;
+            case Pos_IndustrySpecific : IndustrySpecificHeader_Cineon(); break;
+            case Pos_UserDefined      : UserDefinedHeader_Cineon(); break;
             case Pos_Padding          : Padding(); break;
             case Pos_ImageData        : ImageData(); break;
             default                   : ;
@@ -408,9 +404,9 @@ void File_Dpx::Data_Parse()
     {
         switch (Element_Code)
         {
-            case Pos_GenericSection   : GenericSectionHeader_v2(); break;
-            case Pos_IndustrySpecific : IndustrySpecificHeader_v2(); break;
-            case Pos_UserDefined      : UserDefinedHeader_v2(); break;
+            case Pos_GenericSection   : GenericSectionHeader_Dpx(); break;
+            case Pos_IndustrySpecific : IndustrySpecificHeader_Dpx(); break;
+            case Pos_UserDefined      : UserDefinedHeader_Dpx(); break;
             case Pos_Padding          : Padding(); break;
             case Pos_ImageData        : ImageData(); break;
             default                   : ;
@@ -437,13 +433,14 @@ void File_Dpx::Data_Parse()
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-void File_Dpx::GenericSectionHeader_v1()
+void File_Dpx::GenericSectionHeader_Cineon()
 {
     Element_Name("Generic section header");
 
     //Parsing
     Element_Begin1("File information");
     Ztring CreationDate, CreationTime;
+    string Version;
     int32u Size_Header, Size_Total, Size_Generic, Size_Industry, Size_User;
     Skip_B4(                                                    "Magic number");
     Get_X4 (Size_Header,                                        "Offset to image data");
@@ -451,7 +448,7 @@ void File_Dpx::GenericSectionHeader_v1()
     Get_X4 (Size_Industry,                                      "Industry specific header length");
     Get_X4 (Size_User,                                          "User-defined header length");
     Get_X4 (Size_Total,                                         "Total image file size");
-    Skip_String(8,                                              "Version number of header format");
+    Get_String(8, Version,                                      "Version number of header format");
     Skip_UTF8  (100,                                            "FileName");
     Get_UTF8   (12,  CreationDate,                              "Creation Date");
     Get_UTF8   (12,  CreationTime,                              "Creation Time");
@@ -466,17 +463,17 @@ void File_Dpx::GenericSectionHeader_v1()
     if (ImageElements>8)
         ImageElements=8;
     for(int8u ImageElement=0; ImageElement<ImageElements; ImageElement++)
-        GenericSectionHeader_v1_ImageElement();
+        GenericSectionHeader_Cineon_ImageElement();
     if (ImageElements!=8)
         Skip_XX((8-ImageElements)*28,                           "Padding");
-    Skip_BFP4(9,                                                "White point - x");
-    Skip_BFP4(9,                                                "White point - y");
-    Skip_BFP4(9,                                                "Red primary chromaticity - x");
-    Skip_BFP4(9,                                                "Red primary chromaticity - u");
-    Skip_BFP4(9,                                                "Green primary chromaticity - x");
-    Skip_BFP4(9,                                                "Green primary chromaticity - y");
-    Skip_BFP4(9,                                                "Blue primary chromaticity - x");
-    Skip_BFP4(9,                                                "Blue primary chromaticity - y");
+    Skip_BF4(                                                   "White point - x");
+    Skip_BF4(                                                   "White point - y");
+    Skip_BF4(                                                   "Red primary chromaticity - x");
+    Skip_BF4(                                                   "Red primary chromaticity - u");
+    Skip_BF4(                                                   "Green primary chromaticity - x");
+    Skip_BF4(                                                   "Green primary chromaticity - y");
+    Skip_BF4(                                                   "Blue primary chromaticity - x");
+    Skip_BF4(                                                   "Blue primary chromaticity - y");
     Skip_UTF8(200,                                              "Label text");
     Skip_XX(28,                                                 "Reserved for future use");
     Element_End0();
@@ -499,9 +496,9 @@ void File_Dpx::GenericSectionHeader_v1()
     Skip_UTF8(64,                                               "Input device");
     Skip_UTF8(32,                                               "Input device model number");
     Skip_UTF8(32,                                               "Input device serial number");
-    Skip_BFP4(9,                                                "X input device pitch");
-    Skip_BFP4(9,                                                "Y input device pitch");
-    Skip_BFP4(9,                                                "Image gamma of capture device");
+    Skip_BF4(                                                   "X input device pitch");
+    Skip_BF4(                                                   "Y input device pitch");
+    Skip_BF4(                                                   "Image gamma of capture device");
     Skip_XX(40,                                                 "Reserved for future use");
     Element_End0();
 
@@ -527,12 +524,17 @@ void File_Dpx::GenericSectionHeader_v1()
         {
             Fill(Stream_General, 0, General_Encoded_Date, CreationDate+__T(' ')+CreationTime); //ToDo: transform it in UTC
             Fill(StreamKind_Last, StreamPos_Last, "Encoded_Date", CreationDate+__T(' ')+CreationTime); //ToDo: transform it in UTC
+            Fill(StreamKind_Last, StreamPos_Last, "Format", "Cineom");
+            if (Version.size()>2 && Version[0]=='V' && Version[1]>='0' && Version[2]<='9')
+                Version.insert(1, "ersion ");
+            Fill(StreamKind_Last, StreamPos_Last, "Format_Version", Version);
+            Fill(Stream_General, 0, General_Format_Version, Version);
         }
     FILLING_END();
 }
 
 //---------------------------------------------------------------------------
-void File_Dpx::GenericSectionHeader_v1_ImageElement()
+void File_Dpx::GenericSectionHeader_Cineon_ImageElement()
 {
     Element_Begin1("image element");
     int32u Width, Height;
@@ -542,17 +544,15 @@ void File_Dpx::GenericSectionHeader_v1_ImageElement()
     Skip_B1(                                                    "Unused");
     Get_X4 (Width,                                              "Pixels per line");
     Get_X4 (Height,                                             "Lines per image element");
-    Skip_BFP4(9,                                                "Minimum data value");
-    Skip_BFP4(9,                                                "Minimum quantity represented");
-    Skip_BFP4(9,                                                "Maximum data value");
-    Skip_BFP4(9,                                                "Maximum quantity represented");
+    Skip_BF4(                                                   "Minimum data value");
+    Skip_BF4(                                                   "Minimum quantity represented");
+    Skip_BF4(                                                   "Maximum data value");
+    Skip_BF4(                                                   "Maximum quantity represented");
     Element_End0();
 
     FILLING_BEGIN();
         if (Frame_Count==0)
         {
-            Fill(StreamKind_Last, StreamPos_Last, "Format", "DPX");
-            Fill(StreamKind_Last, StreamPos_Last, "Format_Version", "Version 1");
             Fill(StreamKind_Last, StreamPos_Last, "Width", Width);
             Fill(StreamKind_Last, StreamPos_Last, "Height", Height);
         }
@@ -560,17 +560,17 @@ void File_Dpx::GenericSectionHeader_v1_ImageElement()
 }
 
 //---------------------------------------------------------------------------
-void File_Dpx::GenericSectionHeader_v2()
+void File_Dpx::GenericSectionHeader_Dpx()
 {
     Element_Name("Generic section header");
 
     //Parsing
     Element_Begin1("File information");
-    std::string CreationDate, Creator, Project, Copyright;
+    std::string Version, CreationDate, Creator, Project, Copyright;
     int32u Size_Header, Size_Total, Size_Generic, Size_Industry, Size_User;
     Skip_String(4,                                              "Magic number");
     Get_X4 (Size_Header,                                        "Offset to image data");
-    Skip_String(8,                                              "Version number of header format");
+    Get_String(8, Version,                                      "Version number of header format");
     Get_X4 (Size_Total,                                         "Total image file size");
     Skip_B4(                                                    "Ditto Key");
     Get_X4 (Size_Generic,                                       "Generic section header length");
@@ -595,7 +595,7 @@ void File_Dpx::GenericSectionHeader_v2()
     Get_X4 (Width,                                              "Pixels per line");
     Get_X4 (Height,                                             "Lines per image element");
     for(int16u ImageElement=0; ImageElement<ImageElements; ImageElement++)
-        GenericSectionHeader_v2_ImageElement();
+        GenericSectionHeader_Dpx_ImageElement();
     if (ImageElements!=8)
         Skip_XX((8-ImageElements)*72,                           "Padding");
     Skip_XX(52,                                                 "Reserved for future use");
@@ -604,8 +604,8 @@ void File_Dpx::GenericSectionHeader_v2()
     Element_Begin1("Image source information");
     Skip_B4(                                                    "X Offset");
     Skip_B4(                                                    "Y Offset");
-    Skip_BFP4(9,                                                "X center");
-    Skip_BFP4(9,                                                "Y center");
+    Skip_BF4(                                                   "X center");
+    Skip_BF4(                                                   "Y center");
     Skip_B4(                                                    "X original size");
     Skip_B4(                                                    "Y original size");
     Skip_UTF8(100,                                              "Source image filename");
@@ -622,8 +622,8 @@ void File_Dpx::GenericSectionHeader_v2()
     Get_X4 (PAR_V,                                              "Pixel ratio : vertical");
 
     Element_Begin1("Additional source image information");
-    Skip_BFP4(9,                                                "X scanned size");
-    Skip_BFP4(9,                                                "Y scanned size");
+    Skip_BF4(                                                   "X scanned size");
+    Skip_BF4(                                                   "Y scanned size");
     Skip_XX(20,                                                 "Reserved for future use");
     Element_End0();
 
@@ -659,6 +659,11 @@ void File_Dpx::GenericSectionHeader_v2()
             Fill(StreamKind_Last, StreamPos_Last, "Encoded_Library", Creator);
             Fill(Stream_General, 0, "Project", Project); //ToDo: map to a MediaInfo field (which one?)
             Fill(Stream_General, 0, General_Copyright, Copyright);
+            Fill(StreamKind_Last, StreamPos_Last, "Format", "DPX");
+            if (Version.size()>2 && Version[0]=='V' && Version[1]>='0' && Version[2]<='9')
+                Version.insert(1, "ersion ");
+            Fill(StreamKind_Last, StreamPos_Last, "Format_Version", Version);
+            Fill(Stream_General, 0, General_Format_Version, Version);
 
             Fill(StreamKind_Last, StreamPos_Last, "Width", Width);
             Fill(StreamKind_Last, StreamPos_Last, "Height", Height);
@@ -671,15 +676,15 @@ void File_Dpx::GenericSectionHeader_v2()
 }
 
 //---------------------------------------------------------------------------
-void File_Dpx::GenericSectionHeader_v2_ImageElement()
+void File_Dpx::GenericSectionHeader_Dpx_ImageElement()
 {
     Element_Begin1("image element");
     int8u TransferCharacteristic, ColorimetricSpecification, BitDephs;
     Info_B4(DataSign,                                           "Data sign");Param_Info1((DataSign==0?"unsigned":"signed"));
     Skip_B4(                                                    "Reference low data code value");
-    Skip_BFP4(9,                                                "Reference low quantity represented");
+    Skip_BF4(                                                   "Reference low quantity represented");
     Skip_B4(                                                    "Reference high data code value");
-    Skip_BFP4(9,                                                "Reference high quantity represented");
+    Skip_BF4(                                                   "Reference high quantity represented");
     Info_B1(Descriptor,                                         "Descriptor");Param_Info1(DPX_Descriptors(Descriptor));
     Get_B1 (TransferCharacteristic,                             "Transfer characteristic");Param_Info1(DPX_TransferCharacteristic(TransferCharacteristic));
     Get_B1 (ColorimetricSpecification,                          "Colorimetric specification");Param_Info1(DPX_ColorimetricSpecification(ColorimetricSpecification));
@@ -695,8 +700,6 @@ void File_Dpx::GenericSectionHeader_v2_ImageElement()
     FILLING_BEGIN();
         if (Frame_Count==0)
         {
-            Fill(StreamKind_Last, StreamPos_Last, "Format", "DPX");
-            Fill(StreamKind_Last, StreamPos_Last, "Format_Version", "Version 2");
             Fill(StreamKind_Last, StreamPos_Last, "BitDepth", BitDephs);
             Fill(StreamKind_Last, StreamPos_Last, "colour_description_present", "Yes");
             Fill(StreamKind_Last, StreamPos_Last, "colour_primaries", DPX_TransferCharacteristic(TransferCharacteristic));
@@ -706,7 +709,7 @@ void File_Dpx::GenericSectionHeader_v2_ImageElement()
 }
 
 //---------------------------------------------------------------------------
-void File_Dpx::IndustrySpecificHeader_v1()
+void File_Dpx::IndustrySpecificHeader_Cineon()
 {
     Element_Name("Motion picture industry specific header");
 
@@ -728,7 +731,7 @@ void File_Dpx::IndustrySpecificHeader_v1()
 }
 
 //---------------------------------------------------------------------------
-void File_Dpx::IndustrySpecificHeader_v2()
+void File_Dpx::IndustrySpecificHeader_Dpx()
 {
     Element_Name("Industry specific header");
 
@@ -743,8 +746,8 @@ void File_Dpx::IndustrySpecificHeader_v2()
     Skip_B4(                                                    "Frame position in sequence");
     Skip_B4(                                                    "Sequence length (frames)");
     Skip_B4(                                                    "Held count (1 = default)");
-    Skip_BFP4(9,                                                "Frame rate of original (frames/s)");
-    Skip_BFP4(9,                                                "Shutter angle of camera in degrees");
+    Skip_BF4(                                                   "Frame rate of original (frames/s)");
+    Skip_BF4(                                                   "Shutter angle of camera in degrees");
     Skip_UTF8(32,                                               "Frame identification - e.g. keyframe");
     Skip_UTF8(100,                                              "Slate information");
     Skip_XX(56,                                                 "Reserved for future use");
@@ -757,22 +760,22 @@ void File_Dpx::IndustrySpecificHeader_v2()
     Skip_B1(                                                    "Field number");
     Info_B1(VideoSignalStandard,                                "Video signal standard");Param_Info1(DPX_VideoSignalStandard(VideoSignalStandard));
     Skip_B1(                                                    "Zero");
-    Skip_BFP4(9,                                                "Horizontal sampling rate (Hz)");
-    Skip_BFP4(9,                                                "Vertical sampling rate (Hz)");
-    Skip_BFP4(9,                                                "Temporal sampling rate or frame rate (Hz)");
-    Skip_BFP4(9,                                                "Time offset from sync to first pixel (ms)");
-    Skip_BFP4(9,                                                "Gamma");
-    Skip_BFP4(9,                                                "Black level code value");
-    Skip_BFP4(9,                                                "Black gain");
-    Skip_BFP4(9,                                                "Breakpoint");
-    Skip_BFP4(9,                                                "Reference white level code value");
-    Skip_BFP4(9,                                                "Integration time (s)");
+    Skip_BF4(                                                   "Horizontal sampling rate (Hz)");
+    Skip_BF4(                                                   "Vertical sampling rate (Hz)");
+    Skip_BF4(                                                   "Temporal sampling rate or frame rate (Hz)");
+    Skip_BF4(                                                   "Time offset from sync to first pixel (ms)");
+    Skip_BF4(                                                   "Gamma");
+    Skip_BF4(                                                   "Black level code value");
+    Skip_BF4(                                                   "Black gain");
+    Skip_BF4(                                                   "Breakpoint");
+    Skip_BF4(                                                   "Reference white level code value");
+    Skip_BF4(                                                   "Integration time (s)");
     Skip_XX(76,                                                 "Reserved for future use");
     Element_End0();
 }
 
 //---------------------------------------------------------------------------
-void File_Dpx::UserDefinedHeader_v1()
+void File_Dpx::UserDefinedHeader_Cineon()
 {
     Element_Name("User defined header");
 
@@ -781,7 +784,7 @@ void File_Dpx::UserDefinedHeader_v1()
 }
 
 //---------------------------------------------------------------------------
-void File_Dpx::UserDefinedHeader_v2()
+void File_Dpx::UserDefinedHeader_Dpx()
 {
     Element_Name("User defined header");
 
