@@ -164,7 +164,7 @@ void File_Eia708::Read_Buffer_Continue()
 //---------------------------------------------------------------------------
 void File_Eia708::Read_Buffer_Unsynched()
 {
-    for (int8u service_number=1; service_number<Streams.size(); service_number++)
+    for (service_number=1; service_number<Streams.size(); service_number++)
         if (Streams[service_number])
         {
             //Per window
@@ -192,6 +192,12 @@ void File_Eia708::Read_Buffer_Unsynched()
                 }
             }
         }
+
+    #if MEDIAINFO_EVENTS
+        for (service_number=1; service_number<Streams.size(); service_number++)
+            if (Streams[service_number])
+                HasChanged();
+    #endif //MEDIAINFO_EVENTS
 }
 
 //***************************************************************************
@@ -1261,12 +1267,16 @@ void File_Eia708::DFx(int8u WindowID)
     window* Window=Streams[service_number]->Windows[WindowID];
     Window->visible=visible;
     Window->relative_positioning=relative_positioning;
-    Window->anchor_vertical=anchor_vertical;
     if (relative_positioning)
+    {
         Window->Minimal.Window_y=(int8u)(((float)15)*anchor_vertical/100);
+        Window->Minimal.Window_x=(int8u)(24*AspectRatio*anchor_horizontal/100);;
+    }
     else
+    {
         Window->Minimal.Window_y=anchor_vertical/5;
-    Window->anchor_horizontal=anchor_horizontal;
+        Window->Minimal.Window_x=anchor_horizontal/5;
+    }
     int8u offset_y;
     switch (anchor_point)
     {
@@ -1289,10 +1299,6 @@ void File_Eia708::DFx(int8u WindowID)
     }
     if (offset_y<Window->Minimal.Window_y)
         Window->Minimal.Window_y-=offset_y;
-    if (relative_positioning)
-        Window->Minimal.Window_x=(int8u)(24*AspectRatio*anchor_horizontal/100);
-    else
-        Window->Minimal.Window_x=anchor_horizontal/5;
     int8u offset_x;
     switch (anchor_point)
     {
@@ -1320,9 +1326,9 @@ void File_Eia708::DFx(int8u WindowID)
     Window->Minimal.x=0;
     Window->Minimal.y=0;
 
-    if (Window->row_count>12)
+    if (Window->row_count>15)
     {
-        Window->row_count=12; //Limitation of specifications
+        Window->row_count=15; //Limitation of specifications
     }
     if (AspectRatio && Window->column_count>(int8u)(24*AspectRatio))
     {
@@ -1332,17 +1338,14 @@ void File_Eia708::DFx(int8u WindowID)
     for (int8u Pos_Y=0; Pos_Y<Window->row_count; Pos_Y++)
         Window->Minimal.CC[Pos_Y].resize(Window->column_count);
 
-    if (Window->row_count>12)
+    if (Window->Minimal.Window_y+Window->row_count>15 || (AspectRatio && Window->Minimal.Window_x+Window->column_count>(int8u)(24*AspectRatio)))
     {
-        Window->row_count=12; //Limitation of specifications
+        //Correcting
+        if (Window->Minimal.Window_y+Window->row_count>15)
+            Window->Minimal.Window_y=15-Window->row_count;
+        if (AspectRatio && Window->Minimal.Window_x+Window->column_count>(int8u)(24*AspectRatio))
+            Window->Minimal.Window_x=(int8u)(24*AspectRatio)-Window->column_count;
     }
-    if (AspectRatio && Window->column_count>(int8u)(24*AspectRatio))
-    {
-        Window->column_count=(int8u)(24*AspectRatio); //Limitation of specifications
-    }
-    Window->Minimal.CC.resize(Window->row_count);
-    for (int8u Pos_Y=0; Pos_Y<Window->row_count; Pos_Y++)
-        Window->Minimal.CC[Pos_Y].resize(Window->column_count);
 }
 
 //***************************************************************************
